@@ -40,6 +40,7 @@ class FolderChoice(CompleteChoice):
 
 output_option = option("--simple-output", is_flag=True, default=False, help="Simplified output.")
 dry_run_option = option("--dry-run", is_flag=True, default=False, help="Fetch entries without modifying database.")
+verbose_report_option = option("--verbose-report", is_flag=True, default=False, help="Output full report with IDs.")
 
 
 @group("download", cls=CustomHelpColorsGroup, short_help="Download resources.", no_args_is_help=True,
@@ -90,13 +91,14 @@ def download_login(ctx: Context, database: Callable[..., Database]):
 @option("--folder", "-f", "folders", metavar="FOLDER", required=True, multiple=True, type=FolderChoice(),
         callback=lambda _c, _p, v: sorted(set(v), key=v.index), help="Folder to download.")
 @dry_run_option
+@verbose_report_option
 @database_exists_option
 @color_option
 @help_option
 @pass_context
 @docstring_format(', '.join(Folder))
 def download_users(ctx: Context, database: Callable[..., Database], users: tuple[str], folders: tuple[str],
-                   dry_run: bool):
+                   dry_run: bool, verbose_report: bool):
     """
     Download specific user folders, where {yellow}FOLDER{reset} is one of {0}. Multiple {yellow}--user{reset} and
     {yellow}--folder{reset} arguments can be passed.
@@ -111,7 +113,7 @@ def download_users(ctx: Context, database: Callable[..., Database], users: tuple
         downloader.download_users(list(users), list(folders))
     finally:
         echo()
-        downloader.report()
+        downloader.verbose_report() if verbose_report else downloader.report()
 
 
 @download_app.command("update", short_help="Download new entries for users in database.")
@@ -123,13 +125,14 @@ def download_users(ctx: Context, database: Callable[..., Database], users: tuple
         help="Number of submissions to find in the database before stopping.")
 @option("--deactivated", is_flag=True, default=False, help="Check deactivated users.")
 @dry_run_option
+@verbose_report_option
 @database_exists_option
 @color_option
 @help_option
 @pass_context
 @docstring_format(', '.join(Folder))
 def download_update(ctx: Context, database: Callable[..., Database], users: tuple[str], folders: tuple[str], stop: int,
-                    deactivated: bool, dry_run: bool):
+                    deactivated: bool, dry_run: bool, verbose_report: bool):
     """
     Download new entries using the users and folders already in the database. {yellow}--user{reset} and
     {yellow}--folder{reset} options can be used to restrict the update to specific users and or folders, where
@@ -139,8 +142,8 @@ def download_update(ctx: Context, database: Callable[..., Database], users: tupl
     If the {yellow}--deactivated{reset} option is used, deactivated users are fetched instead of ignore. If the user is
     no longer inactive, the database entry will be modified as well.
 
-    The {yellow}--stop{reset} option allows setting after how many entries of each folder should be found in the database
-    before stopping the update.
+    The {yellow}--stop{reset} option allows setting after how many entries of each folder should be found in the
+    database before stopping the update.
 
     The optional {yellow}--dry-run{reset} option disables downloading and saving and simply lists fetched entries.
     Users are not added/deactivated.
@@ -152,7 +155,7 @@ def download_update(ctx: Context, database: Callable[..., Database], users: tupl
         downloader.download_users_update(list(users), list(folders), stop, deactivated)
     finally:
         echo()
-        downloader.report()
+        downloader.verbose_report() if verbose_report else downloader.report()
 
 
 @download_app.command("submissions", short_help="Download single submissions.", no_args_is_help=True)
@@ -160,13 +163,14 @@ def download_update(ctx: Context, database: Callable[..., Database], users: tupl
           callback=lambda _c, _p, v: sorted(set(v), key=v.index))
 @option("--replace", is_flag=True, default=False, show_default=True, help="Replace submissions already in database.")
 @dry_run_option
+@verbose_report_option
 @database_exists_option
 @color_option
 @help_option
 @pass_context
 @docstring_format()
 def download_submissions(ctx: Context, database: Callable[..., Database], submission_id: tuple[int], replace: bool,
-                         dry_run: bool):
+                         dry_run: bool, verbose_report: bool):
     """
     Download single submissions, where {yellow}SUBMISSION_ID{reset} is the ID of the submission.
 
@@ -182,7 +186,7 @@ def download_submissions(ctx: Context, database: Callable[..., Database], submis
         downloader.download_submissions(list(submission_id), replace)
     finally:
         echo()
-        downloader.report()
+        downloader.verbose_report() if verbose_report else downloader.report()
 
 
 @download_app.command("journals", short_help="Download single journals.", no_args_is_help=True)
@@ -190,13 +194,14 @@ def download_submissions(ctx: Context, database: Callable[..., Database], submis
           callback=lambda _c, _p, v: sorted(set(v), key=v.index))
 @option("--replace", is_flag=True, default=False, show_default=True, help="Replace submissions already in database.")
 @dry_run_option
+@verbose_report_option
 @database_exists_option
 @color_option
 @help_option
 @pass_context
 @docstring_format()
 def download_journals(ctx: Context, database: Callable[..., Database], journal_id: tuple[int], replace: bool,
-                      dry_run: bool):
+                      dry_run: bool, verbose_report: bool):
     """
     Download single journals, where {yellow}JOURNAL_ID{reset} is the ID of the journal.
 
@@ -212,7 +217,7 @@ def download_journals(ctx: Context, database: Callable[..., Database], journal_i
         downloader.download_journals(list(journal_id), replace)
     finally:
         echo()
-        downloader.report()
+        downloader.verbose_report() if verbose_report else downloader.report()
 
 
 download_app.list_commands = lambda *_: [
